/*

	Script for installing updated 3D Printer Profiles
	gExistingProfileArray contains a list of the old profiles to be removed
	Zip file of new profiles should be the same name as this script + ".zip"
	
*/

var gExistingProfileArray = new Array ( 
"Makerbot Replicator 1.0.3PP"
);

var strError = localize("$$$/S4W/Dialog/Browsers/Item/NotFound=File Not Found");
var strDone = localize("$$$/ControlsStrings/Done=Done");
var strCannotCopy = localize("$$$/ProfileInstallFail/failed=Profile installation has failed.  Please see readme.txt for details.");

function CreateNewDocument()
{
	// =======================================================
var idMk = charIDToTypeID( "Mk  " );
    var desc1 = new ActionDescriptor();
    var idNw = charIDToTypeID( "Nw  " );
        var desc2 = new ActionDescriptor();
        var idMd = charIDToTypeID( "Md  " );
        var idRGBM = charIDToTypeID( "RGBM" );
        desc2.putClass( idMd, idRGBM );
        var idWdth = charIDToTypeID( "Wdth" );
        var idRlt = charIDToTypeID( "#Rlt" );
        desc2.putUnitDouble( idWdth, idRlt, 504.000000 );
        var idHght = charIDToTypeID( "Hght" );
        var idRlt = charIDToTypeID( "#Rlt" );
        desc2.putUnitDouble( idHght, idRlt, 360.000000 );
        var idRslt = charIDToTypeID( "Rslt" );
        var idRsl = charIDToTypeID( "#Rsl" );
        desc2.putUnitDouble( idRslt, idRsl, 72.000000 );
        var idpixelScaleFactor = stringIDToTypeID( "pixelScaleFactor" );
        desc2.putDouble( idpixelScaleFactor, 1.000000 );
        var idFl = charIDToTypeID( "Fl  " );
        var idFl = charIDToTypeID( "Fl  " );
        var idWht = charIDToTypeID( "Wht " );
        desc2.putEnumerated( idFl, idFl, idWht );
        var idDpth = charIDToTypeID( "Dpth" );
        desc2.putInteger( idDpth, 8 );
        var idprofile = stringIDToTypeID( "profile" );
        desc2.putString( idprofile, "sRGB IEC61966-2.1" );
    var idDcmn = charIDToTypeID( "Dcmn" );
    desc1.putObject( idNw, idDcmn, desc2 );
    executeAction( idMk, desc1, DialogModes.NO );


}
function CloseWithoutSave()
{
// =======================================================
var idClssp = charIDToTypeID( "Cls " );
    var desc30 = new ActionDescriptor();
    var idSvng = charIDToTypeID( "Svng" );
    var idYsNsp = charIDToTypeID( "YsN " );
    var idNspspsp = charIDToTypeID( "N   " );
    desc30.putEnumerated( idSvng, idYsNsp, idNspspsp );
executeAction( idClssp, desc30, DialogModes.NO );

}
function ResetPrintProfiles()
{
	var desc3 = new ActionDescriptor();
	executeAction( stringIDToTypeID( "setPrint3DProperties" ), desc3, DialogModes.NO );
}


function CopyProfiles(srcFolderPath, destFolderPath, profileSourceFilesArray)
{
	var sourceFolder = new Folder(srcFolderPath);
	if(sourceFolder == null) {
		return 1;
	}
	
	var index;
	for(index = 0; index < profileSourceFilesArray.length; index++)
	{
		var profilePath = new File(srcFolderPath + unescape(profileSourceFilesArray[index]));
		//alert(profilePath);
		if(profilePath.exists)
		{
			var destFilePath = destFolderPath + unescape(profileSourceFilesArray[index]);
			//alert(destFilePath);
			profilePath.copy(destFilePath);
			profilePath.close();
			
			var filePathToWrite = new File(destFilePath);
			if(!filePathToWrite.exists)
			{
				alert(strCannotCopy);
	 			return 1;
	 		}
		}
	}
	
	return 0;
}

function DeleteExistingProfiles(printerProfilesPath, profilesToDelete)
{
	var index;
	var numProfiles = profilesToDelete.length;
	for(index = 0; index < numProfiles; index++)
	{
		var profilePath = printerProfilesPath + profilesToDelete[index];
		var dataFile = new File(profilePath);
		if(dataFile == null) {
			continue;
		}
		if(dataFile.exists)
			dataFile.remove();
	}
}

function InstallFolderFound(folderObject)
{
	if(folderObject.length == undefined)
	{
		//This is a folder - no length
		//There's probably a better way to check this, but this works
		//alert("Found Folder " + folderObject);		
		var profileSourceFilesArray = new Array();
		var profileDeleteFilesArray = new Array();
		var destFolderPath="";
			
		var manifestFile = new File(unescape(folderObject + "/manifest.csv"));
		//alert(manifestPath);
		if(!manifestFile.exists)
			return;
			
		if(manifestFile.exists)
		{
			//alert("Found " + manifestFile);
			manifestFile.open();
			
			var endOfDeletedFilesFound=false;
			var manifestLine = manifestFile.readln();
			//alert(manifestLine);
			
			while(manifestLine != "")
			{
				if(manifestLine[0] == '#')
				{
					//Comment line - skip it
				}
				else if(manifestLine == "END")
				{
					endOfDeletedFilesFound = true;
				}
				else
				{
					if(endOfDeletedFilesFound)
						{
						if(destFolderPath != "")
							{
							//alert("Source File: " + manifestLine);
							profileSourceFilesArray[profileSourceFilesArray.length] = manifestLine;
							}
						else
							{
							//alert("Dest Folder: " + manifestLine);
							destFolderPath = manifestLine;
							}
						}
					else
						{
						//alert("File to Delete: " + manifestLine);
						profileDeleteFilesArray[profileDeleteFilesArray.length] = manifestLine;
						}
				}
				manifestLine = manifestFile.readln();
			}
			manifestFile.close();
		}
		
		if(!profileSourceFilesArray.length || !profileDeleteFilesArray.length || destFolderPath == "")
		{
			alert(strCannotCopy);
			return;
		}
		
		var printerProfilesPath = app.path + "/Presets/3D Printers";
		DeleteExistingProfiles(printerProfilesPath, profileDeleteFilesArray);
		
		var destProfilesPath = printerProfilesPath + destFolderPath;
		if(!destProfilesPath.exists)
		{
			var destFolder = new Folder(destProfilesPath);
			destFolder.create();
		}
		
		if(CopyProfiles(unescape(folderObject), destProfilesPath, profileSourceFilesArray))
		{
			//Copy returned an error
			return;
		}
		
		
		//Have the UI refresh what profiles are installed
		CreateNewDocument();
		ResetPrintProfiles();
		CloseWithoutSave();
		
	}
	else
	{
		//alert("Found File " + folderObject);
	}
}

function CheckPermissions(pathToCheck)
{
	 var filePathToWrite = new File(pathToCheck + "permCheck.txt");
	 filePathToWrite.open("w");
	 if(filePathToWrite.exists)
	 {
	 	//alert("Created " + filePathToWrite);
	 	filePathToWrite.close();
	 	filePathToWrite.remove();
	 	return true;
	 }
	 
	 alert(strCannotCopy);
	 return false;
}

function InstallProfiles()
{
	var printerProfilesPath = app.path + "/Presets/3D Printers/";
	
	if(!CheckPermissions(printerProfilesPath))
		return;
		
	var sourceProfilesPath = (new File($.fileName)).parent;//$.fileName.slice(0, -4);
	var sourceFolder = new Folder(sourceProfilesPath);
	var folderList = sourceFolder.getFiles(InstallFolderFound);
	
	alert(strDone);
	
}

InstallProfiles();